//##############################################################################
//    filename:        lcd_config.h
//##############################################################################
//    configuration file for LCD library (pins, voltage, ...)
//##############################################################################
//
//      Author:            	V.SchK
//      Company:        	HS-Ulm
//
//      Revision:        	2.0
// 	    Date:               Nov. 2014
//     	Assembled using		C18 3.41+ / XC8 1.30+
//
//##############################################################################

#ifndef _LCD_CONFIG_H
#define _LCD_CONFIG_H

#if defined(__XC8)          // XC8 compiler
    #include <xc.h>
#else                       // C18 compiler (#ifdef __18CXX)
    #include <p18cxxx.h>
    #include <delays.h>

    #define const const rom
#endif


#define LCD_TIMEOUT 100

#define LCD_DELAY_5MS() Delay10KTCYx(1) // 1tcy = 1us (FOSC 4.000.000)
#define LCD_DELAY_1US() Nop()//;Nop();Nop();Nop();
#warning "be sure to define LCD-Delays properly !!!"


// uncomment the board in use or define a custom pinnig ;-) --------------------
    #define uC_QUICK

//    #define PICDEM2p_2002
//    #define PICDEM2p_2006

//    #define PIC_ADAPTER
//    #define EXT_LCD_3_3_V   //DOG... displays
//    #define EXT_LCD_5_V

//    #define MINI_AD_LCD
//    #define MINI_RS232_LCD
//    #define MINI_...

//      custom boards at the end

    #if defined uC_QUICK
        #warning "LCD-pinning for uC-Quick board !!!"
        #define	LCD_E		LATCbits.LATC1
        #define	LCD_E_DIR	TRISCbits.TRISC1
        #define	LCD_RW		LATCbits.LATC0
        #define	LCD_RW_DIR	TRISCbits.TRISC0
        #define	LCD_RS		LATAbits.LATA5
        #define	LCD_RS_DIR	TRISAbits.TRISA5

        #define	LCD_D4_IN	PORTBbits.RB2
        #define	LCD_D5_IN	PORTBbits.RB3
        #define	LCD_D6_IN	PORTBbits.RB4
        #define	LCD_D7_IN	PORTBbits.RB5
        #define	LCD_D4_OUT	LATBbits.LATB2
        #define	LCD_D5_OUT	LATBbits.LATB3
        #define	LCD_D6_OUT	LATBbits.LATB4
        #define	LCD_D7_OUT	LATBbits.LATB5
        #define	LCD_D4_DIR	TRISBbits.TRISB2
        #define	LCD_D5_DIR	TRISBbits.TRISB3
        #define	LCD_D6_DIR	TRISBbits.TRISB4
        #define	LCD_D7_DIR	TRISBbits.TRISB5

    #elif defined  PICDEM2p_2002
        #warning "LCD-pinning for PICDEM2+ 2002 !!!"
        #define	LCD_E		LATAbits.LATA1
        #define	LCD_E_DIR	TRISAbits.TRISA1
        #define	LCD_RW		LATAbits.LATA2
        #define	LCD_RW_DIR	TRISAbits.TRISA2
        #define	LCD_RS		LATAbits.LATA3
        #define	LCD_RS_DIR	TRISAbits.TRISA3

        #define	LCD_D4_IN	PORTDbits.RD0
        #define	LCD_D5_IN	PORTDbits.RD1
        #define	LCD_D6_IN	PORTDbits.RD2
        #define	LCD_D7_IN	PORTDbits.RD3
        #define	LCD_D4_OUT	LATDbits.LATD0
        #define	LCD_D5_OUT	LATDbits.LATD1
        #define	LCD_D6_OUT	LATDbits.LATD2
        #define	LCD_D7_OUT	LATDbits.LATD3
        #define	LCD_D4_DIR	TRISDbits.TRISD0
        #define	LCD_D5_DIR	TRISDbits.TRISD1
        #define	LCD_D6_DIR	TRISDbits.TRISD2
        #define	LCD_D7_DIR	TRISDbits.TRISD3

    #elif defined(PICDEM2p_2006) || defined(PIC_ADAPTER)
        #warning "LCD-pinning for PICDEM2+ 2006 !!!"
        #define	LCD_E		LATDbits.LATD6
        #define	LCD_E_DIR	TRISDbits.TRISD6
        #define	LCD_RW		LATDbits.LATD5
        #define	LCD_RW_DIR	TRISDbits.TRISD5
        #define	LCD_RS		LATDbits.LATD4
        #define	LCD_RS_DIR	TRISDbits.TRISD4

        #define	LCD_D4_IN	PORTDbits.RD0
        #define	LCD_D5_IN	PORTDbits.RD1
        #define	LCD_D6_IN	PORTDbits.RD2
        #define	LCD_D7_IN	PORTDbits.RD3
        #define	LCD_D4_OUT	LATDbits.LATD0
        #define	LCD_D5_OUT	LATDbits.LATD1
        #define	LCD_D6_OUT	LATDbits.LATD2
        #define	LCD_D7_OUT	LATDbits.LATD3
        #define	LCD_D4_DIR	TRISDbits.TRISD0
        #define	LCD_D5_DIR	TRISDbits.TRISD1
        #define	LCD_D6_DIR	TRISDbits.TRISD2
        #define	LCD_D7_DIR	TRISDbits.TRISD3

    #elif defined  MINI_AD_LCD
        #warning "LCD-pinning for MINI_AD_LCD board !!!"
        #define	LCD_E		LATBbits.LATB2
        #define	LCD_E_DIR	TRISBbits.TRISB2
        #define	LCD_RW		LATBbits.LATB3
        #define	LCD_RW_DIR	TRISBbits.TRISB3
        #define	LCD_RS		LATAbits.LATA0
        #define	LCD_RS_DIR	TRISAbits.TRISA0

        #define	LCD_D4_IN	PORTAbits.RA7
        #define	LCD_D4_OUT	LATAbits.LATA7
        #define	LCD_D4_DIR	TRISAbits.TRISA7

        #define	LCD_D5_IN	PORTAbits.RA6
        #define	LCD_D5_OUT	LATAbits.LATA6
        #define	LCD_D5_DIR	TRISAbits.TRISA6

        #define	LCD_D6_IN	PORTBbits.RB4
        #define	LCD_D6_OUT	LATBbits.LATB4
        #define	LCD_D6_DIR	TRISBbits.TRISB4

        #define	LCD_D7_IN	PORTBbits.RB5
        #define	LCD_D7_OUT	LATBbits.LATB5
        #define	LCD_D7_DIR	TRISBbits.TRISB5

    #elif defined MINI_RS232_LCD
        #warning "LCD-pinning for MINI_RS232_LCD board !!!"
        #define	LCD_E		LATAbits.LATA1
        #define	LCD_E_DIR	TRISAbits.TRISA1
        #define	LCD_RW		LATAbits.LATA4
        #define	LCD_RW_DIR	TRISAbits.TRISA4	
        #define	LCD_RS		LATAbits.LATA2
        #define	LCD_RS_DIR	TRISAbits.TRISA2

        #define	LCD_D4_IN	PORTBbits.RB5
        #define	LCD_D5_IN	PORTAbits.RA6
        #define	LCD_D6_IN	PORTAbits.RA7
        #define	LCD_D7_IN	PORTBbits.RB2

        #define	LCD_D4_OUT	LATBbits.LATB5
        #define	LCD_D5_OUT	LATAbits.LATA6
        #define	LCD_D6_OUT	LATAbits.LATA7
        #define	LCD_D7_OUT	LATBbits.LATB2

        #define	LCD_D4_DIR	TRISBbits.TRISB5
        #define	LCD_D5_DIR	TRISAbits.TRISA6
        #define	LCD_D6_DIR	TRISAbits.TRISA7
        #define	LCD_D7_DIR	TRISBbits.TRISB2

    #else
        #error PLEASE SPECIFY LCD CONNECTIONS !
    #endif

  #ifdef PICDEM2p_2006
    #define LCD_ON      LATDbits.LATD7
    #define LCD_ON_DIR  TRISDbits.TRISD7
  #endif
#endif //_LCD_CONFIG_H
